#[non_exhaustive]pub struct MarkerError {
pub path: String,
pub line: u32,
pub message: String,
}Expand description
One malformed marker: where it is and what is wrong with it.
Displays as path:line: message, the line patchcov lint-markers prints in the
default format; the parts are fields so --error-format json can print them as data.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.path: StringThe file the marker is in, as passed to scan.
line: u32The 1-based line of the marker (of the opening marker, for an unterminated region).
message: StringWhat is wrong, without the path:line: prefix.